Struct security_framework::secure_transport::SslClientCertificateState [−][src]
pub struct SslClientCertificateState(_);
Specifies the state of client certificate processing.
Implementations
impl SslClientCertificateState[src]
impl SslClientCertificateState[src]pub const NONE: SslClientCertificateState[src]
pub const NONE: SslClientCertificateState[src]A client certificate has not been requested or sent.
pub const REQUESTED: SslClientCertificateState[src]
pub const REQUESTED: SslClientCertificateState[src]A client certificate has been requested but not recieved.
pub const SENT: SslClientCertificateState[src]
pub const SENT: SslClientCertificateState[src]A client certificate has been received and successfully validated.
pub const REJECTED: SslClientCertificateState[src]
pub const REJECTED: SslClientCertificateState[src]A client certificate has been received but has failed to validate.